@@ -10,7 +10,15 @@ class ExtraMetaConfig(BaseConfig):
     FIELD_IS_PURE = 'is_pure'
 
     def __call__(self, config, facility_section_name):
-        util.D1_D2_SETUP_ARGS[ExtraMetaConfig.FIELD_IS_PURE] = ("metadata",)
+        try:
+            # PBR 5.6.0 and later
+            # Add a tuple of a tuple and a string, to the end of a tuple: 3 parens.
+            util.CFG_TO_PY_SETUP_ARGS += (
+                (("metadata", ExtraMetaConfig.FIELD_IS_PURE), ExtraMetaConfig.FIELD_IS_PURE),
+            )
+        except AttributeError:
+            # Before PBR 5.6.0
+            util.D1_D2_SETUP_ARGS[ExtraMetaConfig.FIELD_IS_PURE] = ("metadata",)
 
         meta_config = config.setdefault('metadata', {})
 
